@@ -58,10 +58,6 @@ function Base.searchsortedlast(lookup::Lookup, val; lt=<, kw...)
     searchsortedlast(parent(lookup), unwrap(val); order=ordering(order(lookup)), lt=lt, kw...)
 end
 
-function Adapt.adapt_structure(to, l::Lookup)
-    rebuild(l; data=Adapt.adapt(to, parent(l)))
-end
-
 """
     AutoLookup <: Lookup
 
@@ -201,10 +197,6 @@ for f in (:getindex, :view, :dotview)
     end
 end
 
-function Adapt.adapt_structure(to, l::AbstractSampled)
-    rebuild(l; data=Adapt.adapt(to, parent(l)), metadata=NoMetadata(), span=Adapt.adapt(to, span(l)))
-end
-
 # bounds
 bounds(l::AbstractSampled) = _bounds(order(l), sampling(l), l)
 
@@ -325,6 +317,9 @@ function rebuild(l::Sampled;
     Sampled(data, order, span, sampling, metadata)
 end
 
+Base.unsafe_convert(::Type{Ptr{T}}, x::Sampled) where {T} = Base.unsafe_convert(Ptr{T}, x.data)
+Base.strides(x::Sampled) = strides(x.data)
+
 # These are used to specialise dispatch:
 # When Cycling, we need to modify any `Selector`. After that
 # we switch to `NotCycling` and use `AbstractSampled` fallbacks.
@@ -470,10 +465,6 @@ metadata(lookup::AbstractCategorical) = lookup.metadata
 
 const CategoricalEltypes = Union{AbstractChar,Symbol,AbstractString}
 
-function Adapt.adapt_structure(to, l::AbstractCategorical)
-    rebuild(l; data=Adapt.adapt(to, parent(l)), metadata=NoMetadata())
-end
-
 
 """
     Categorical <: AbstractCategorical
@@ -987,4 +978,4 @@ function promote_first(a1::AbstractArray, as::AbstractArray...)
     end
 
     return convert(C, a1)
-end
\ No newline at end of file
+end
