@@ -108,6 +108,9 @@ Base.iterate(A::AbstractDimArray, args...) = iterate(parent(A), args...)
 Base.IndexStyle(A::AbstractDimArray) = Base.IndexStyle(parent(A))
 Base.parent(A::AbstractDimArray) = data(A)
 Base.vec(A::AbstractDimArray) = vec(parent(A))
+Base.unsafe_convert(::Type{Ptr{T}}, x::AbstractDimArray) where {T} = Base.unsafe_convert(Ptr{T}, parent(x))
+Base.strides(x::AbstractDimArray) = strides(parent(x))
+
 # Only compare data and dim - metadata and refdims can be different
 Base.:(==)(A1::AbstractDimArray, A2::AbstractDimArray) =
     parent(A1) == parent(A2) && dims(A1) == dims(A2)
@@ -170,8 +173,6 @@ end
 # An alternative would be to fill missing dims with `Anon`, and keep existing
 # dims but strip the Lookup? It just seems a little complicated when the methods
 # below using DimTuple work better anyway.
-Base.similar(A::AbstractDimArray, i::Integer, I::Vararg{Integer}; kw...) =
-    similar(A, eltype(A), (i, I...); kw...)
 Base.similar(A::AbstractDimArray, I::Tuple{Int,Vararg{Int}}; kw...) = 
     similar(A, eltype(A), I; kw...)
 Base.similar(A::AbstractDimArray, ::Type{T}, i::Integer, I::Vararg{Integer}; kw...) where T =
@@ -319,18 +320,6 @@ Base.copyto!(dst::AbstractDimArray{T,2} where T, src::LinearAlgebra.AbstractQ) =
 Base.copyto!(dst::PermutedDimsArray, src::AbstractDimArray) = 
     (copyto!(dst, parent(src)); dst)
 
-ArrayInterface.parent_type(::Type{<:AbstractDimArray{T,N,D,A}}) where {T,N,D,A} = A
-
-function Adapt.adapt_structure(to, A::AbstractDimArray)
-    rebuild(A,
-        data=Adapt.adapt(to, parent(A)),
-        dims=Adapt.adapt(to, dims(A)),
-        refdims=Adapt.adapt(to, refdims(A)),
-        name=Name(name(A)),
-        metadata=Adapt.adapt(to, metadata(A)),
-    )
-end
-
 # Concrete implementation ######################################################
 
 """
