@@ -1,6 +1,7 @@
 using DimensionalData, Test, Dates
 using AlgebraOfGraphics
 using CairoMakie
+using CairoMakie: ComputePipeline
 using ColorTypes
 using Unitful, Unitful.DefaultSymbols
 import Distributions
@@ -434,6 +435,18 @@ end
     @test plt[3][] == extrema(lookup(to_value(dd_3d), X))
     @test_throws ArgumentError volume(dd_3d; xdim = Y, ydim = Z, zdim = Y)
 
+    # Test that axis attributes filter type keyword (issue #1167)
+    @testset "axis attributes correctly filtered" begin
+        @testset for plt_fn in (volume, volumeslices),
+            (axis_type, axis_att) in (
+                (LScene, (; show_axis=false)),
+                (Axis3, (; title="test title"))
+            )
+            fig, ax, plt = plt_fn(dd_3d; axis = (; type=axis_type, axis_att...))
+            @test ax isa axis_type
+        end
+    end
+
     x = Observable(1:5)
     y = Observable(11:15)
     z = Observable(21:25)
@@ -635,8 +648,8 @@ end
     fig, ax, _ = violin(A2r)
     violin!(ax, A2r)
     violin!(A2r)
-    @test_throws ArgumentError violin(A2m)
-    @test_throws ArgumentError violin!(ax, A2m)
+    @test_throws ComputePipeline.ResolveException{ArgumentError} violin(A2m)
+    @test_throws ComputePipeline.ResolveException{ArgumentError} violin!(ax, A2m)
 
     fig, ax, _ = rainclouds(A2)
     rainclouds!(ax, A2)
